@@ -363,7 +363,7 @@ GList *path_list_filter(GList *list, gint is_dir_list)
 {
 	GList *work;
 
-	if (file_filter_disable && show_dot_files) return list;
+	if (!is_dir_list && file_filter_disable && show_dot_files) return list;
 
 	work = list;
 	while (work)
@@ -374,7 +374,9 @@ GList *path_list_filter(GList *list, gint is_dir_list)
 		base = filename_from_path(name);
 
 		if ((!show_dot_files && ishidden(base)) ||
-		    (!is_dir_list && !filter_name_exists(base)) )
+		    (!is_dir_list && !filter_name_exists(base)) ||
+		    (is_dir_list && base[0] == '.' && (strcmp(base, GQVIEW_CACHE_LOCAL_THUMB) == 0 ||
+						       strcmp(base, GQVIEW_CACHE_LOCAL_METADATA) == 0)) )
 			{
 			GList *link = work;
 			work = work->next;
