@@ -332,8 +332,7 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 
 	imd = view_window_active_image(vw);
 
-	if ( !(event->state & GDK_CONTROL_MASK) )
-	    switch (event->keyval)
+	switch (event->keyval)
 		{
 		case GDK_Left: case GDK_KP_Left:
 			x -= 1;
@@ -351,6 +350,11 @@ static gint view_window_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpoi
 			y += 1;
 			stop_signal = TRUE;
 			break;
+		}
+
+	if ( !(event->state & GDK_CONTROL_MASK) )
+	    switch (event->keyval)
+		{
 		case GDK_Page_Up: case GDK_KP_Page_Up:
 		case GDK_BackSpace:
 		case 'B': case 'b':
@@ -871,7 +875,7 @@ static ViewWindow *real_view_window_new(const gchar *path, GList *list, Collecti
 	req_size.height = h;
 	gtk_widget_size_allocate(GTK_WIDGET(vw->window), &req_size);
 
-	gtk_widget_set_size_request(vw->imd->eventbox, w, h);
+	gtk_widget_set_size_request(vw->imd->image, w, h);
 
 	gtk_widget_show(vw->window);
 
@@ -1582,6 +1586,8 @@ static void view_real_removed(ViewWindow *vw, const gchar *path, GList *ignore_l
 			image_change_path(imd, path, image_zoom_get_default(imd, zoom_mode));
 			}
 		}
+
+	if (vw->overlay_id != -1) image_overlay_update(imd, vw->overlay_id);
 }
 
 static void view_real_moved(ViewWindow *vw, const gchar *source, const gchar *dest)
