@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2004 John Ellis
+ * (C) 2005 John Ellis
  *
  * Author: John Ellis
  *
@@ -14,7 +14,7 @@
 #define SEARCH_H
 
 
-void search_new(const gchar *path, GList *list);
+void search_new(const gchar *path, const gchar *example_file);
 
 
 void search_maint_renamed(const gchar *source, const gchar *dest);
