@@ -14,6 +14,10 @@
 #define SLIDESHOW_H
 
 
+#define SLIDESHOW_SUBSECOND_PRECISION 10
+#define SLIDESHOW_MIN_SECONDS    0.1
+#define SLIDESHOW_MAX_SECONDS 3600.0
+
 /*
  * It works like this, it uses path_list, if that does not exist, it uses
  * CollectionData, then finally falls back to the layout listing.
