@@ -95,7 +95,7 @@ static gint vdlist_rename_row_cb(TreeEditData *td, const gchar *old, const gchar
 		gchar *buf;
 
 		buf = g_strdup_printf(_("Failed to rename %s to %s."), old, new);
-		warning_dialog("Rename failed", buf, vdl->listview);
+		file_util_warning_dialog("Rename failed", buf, GTK_STOCK_DIALOG_ERROR, vdl->listview);
 		g_free(buf);
 		}
 	else
@@ -336,7 +336,7 @@ static void vdlist_pop_menu_new_cb(GtkWidget *widget, gpointer data)
 		gchar *text;
 
 		text = g_strdup_printf(_("Unable to create folder:\n%s"), new_path);
-		file_util_warning_dialog(_("Error creating folder"), text, vdl->listview);
+		file_util_warning_dialog(_("Error creating folder"), text, GTK_STOCK_DIALOG_ERROR, vdl->listview);
 		g_free(text);
 		}
 	else
@@ -668,7 +668,7 @@ static gint vdlist_auto_scroll_notify_cb(GtkWidget *widget, gint x, gint y, gpoi
 
 	if (!vdl->drop_fd || vdl->drop_list) return FALSE;
 
-	if (vdl->drop_scroll_id == -1) vdl->drop_scroll_id = gtk_idle_add(vdlist_auto_scroll_idle_cb, vdl);
+	if (vdl->drop_scroll_id == -1) vdl->drop_scroll_id = g_idle_add(vdlist_auto_scroll_idle_cb, vdl);
 
 	return TRUE;
 }
@@ -778,9 +778,20 @@ static void vdlist_populate(ViewDirList *vdl)
 
 		fd = work->data;
 
-		if (access_file(fd->path, R_OK | X_OK))
+		if (access_file(fd->path, R_OK | X_OK) && fd->name)
 			{
-			pixbuf = vdl->pf->close;
+			if (fd->name[0] == '.' && fd->name[1] == '\0')
+				{
+				pixbuf = vdl->pf->open;
+				}
+			else if (fd->name[0] == '.' && fd->name[1] == '.' && fd->name[2] == '\0')
+				{
+				pixbuf = vdl->pf->parent;
+				}
+			else
+				{
+				pixbuf = vdl->pf->close;
+				}
 			}
 		else
 			{
@@ -1099,6 +1110,7 @@ ViewDirList *vdlist_new(const gchar *path)
 	g_object_unref(store);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(vdl->listview), FALSE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(vdl->listview), FALSE);
 	g_signal_connect(G_OBJECT(vdl->listview), "row_activated",
 
 			 G_CALLBACK(vdlist_select_cb), vdl);
