@@ -202,7 +202,7 @@ static gint vdtree_rename_row_cb(TreeEditData *td, const gchar *old, const gchar
 		gchar *buf;
 
 		buf = g_strdup_printf(_("Failed to rename %s to %s."), old, new);
-		warning_dialog("Rename failed", buf, vdt->treeview);
+		file_util_warning_dialog("Rename failed", buf, GTK_STOCK_DIALOG_ERROR, vdt->treeview);
 		g_free(buf);
 		}
 	else
@@ -432,7 +432,7 @@ static void vdtree_pop_menu_new_cb(GtkWidget *widget, gpointer data)
 		gchar *text;
 
 		text = g_strdup_printf(_("Unable to create folder:\n%s"), new_path);
-		file_util_warning_dialog(_("Error creating folder"), text, vdt->treeview);
+		file_util_warning_dialog(_("Error creating folder"), text, GTK_STOCK_DIALOG_ERROR, vdt->treeview);
 		g_free(text);
 		}
 	else
@@ -653,14 +653,14 @@ static gint vdtree_dnd_drop_expand_cb(gpointer data)
 
 static void vdtree_dnd_drop_expand_cancel(ViewDirTree *vdt)
 {
-	if (vdt->drop_expand_id != -1) gtk_timeout_remove(vdt->drop_expand_id);
+	if (vdt->drop_expand_id != -1) g_source_remove(vdt->drop_expand_id);
 	vdt->drop_expand_id = -1;
 }
 
 static void vdtree_dnd_drop_expand(ViewDirTree *vdt)
 {
 	vdtree_dnd_drop_expand_cancel(vdt);
-	vdt->drop_expand_id = gtk_timeout_add(1000, vdtree_dnd_drop_expand_cb, vdt);
+	vdt->drop_expand_id = g_timeout_add(1000, vdtree_dnd_drop_expand_cb, vdt);
 }
 
 static void vdtree_drop_update(ViewDirTree *vdt, gint x, gint y)
@@ -728,7 +728,7 @@ static gint vdtree_auto_scroll_notify_cb(GtkWidget *widget, gint x, gint y, gpoi
 
 	if (!vdt->drop_fd || vdt->drop_list) return FALSE;
 
-	if (vdt->drop_scroll_id == -1) vdt->drop_scroll_id = gtk_idle_add(vdtree_auto_scroll_idle_cb, vdt);
+	if (vdt->drop_scroll_id == -1) vdt->drop_scroll_id = g_idle_add(vdtree_auto_scroll_idle_cb, vdt);
 
 	return TRUE;
 }
@@ -1682,6 +1682,7 @@ ViewDirTree *vdtree_new(const gchar *path, gint expand)
 	g_object_unref(store);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(vdt->treeview), FALSE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(vdt->treeview), FALSE);
 	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), vdtree_sort_cb, vdt, NULL);
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store),
 					     GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
